class SelectManager {
	constructor(containerSelector, selectSelector) {
		this.container = document.querySelector(containerSelector);
		this.selectSelector = selectSelector;
		this.init();
	}

	init() {
		this.container.addEventListener("click", (e) => {
			const targetSelect = e.target.closest(this.selectSelector);
			if (targetSelect) {
				this.handleSelectClick(targetSelect);
			} else {
				this.closeAllSelects();
			}
		});

		document.addEventListener("click", (e) => {
			if (
				!e.target.closest(this.selectSelector) &&
				!e.target.closest(".select-list")
			) {
				this.closeAllSelects();
			}
		});
	}

	handleSelectClick(select) {
		const field = select.querySelector(".select-field");
		const list = select.querySelector(".select-list");

		this.closeOtherSelects(field);

		list.classList.toggle("open");
		field.classList.toggle("turn");

		list.addEventListener("click", (e) => {
			e.stopPropagation();
		});

		const selectItemClickHandler = (e) => {
			const selectedItem = e.target.closest("li");
			if (selectedItem) {
				const result = selectedItem.textContent.trim();
				field.value = "按年份搜索：" + result;
				list.classList.remove("open");
				field.classList.remove("turn");
				list.removeEventListener("click", selectItemClickHandler);
			}
		};

		list.addEventListener("click", selectItemClickHandler);
	}

	closeOtherSelects(clickedField) {
		var selects = this.container.querySelectorAll(this.selectSelector);
		for (var i = 0; i < selects.length; i++) {
			var select = selects[i];
			var field = select.querySelector(".select-field");
			var list = select.querySelector(".select-list");

			if (field && list && field !== clickedField) {
				if (list.classList.contains("open")) {
					list.classList.remove("open");
				}
				if (field.classList.contains("turn")) {
					field.classList.remove("turn");
				}
			}
		}
	}

	closeAllSelects() {
		let selects = this.container.querySelectorAll(this.selectSelector);
		for (let i = 0; i < selects.length; i++) {
			let select = selects[i];
			const field = select.querySelector(".select-field");
			const list = select.querySelector(".select-list");

			if (list && field) {
				list.classList.remove("open");
				field.classList.remove("turn");
			}
		}
	}
}

// Init
const selectManager = new SelectManager("body", ".select");